Veltrix: small utilities for paths, processes, services, and platform helpers.
Re-exports
pub use error::Result;pub use error::VeltrixError as Error;
Modules
- error
- Error types and result alias used by Veltrix helpers. Error types returned by Veltrix helpers.
- os
- OS helpers and common OS-related constants.
- services
- Service integrations such as Podman and Caddy. Introduced in v0.2.0, but still in early stages of development. Service integrations.
- unicode
- Unicode helpers, such as emoji constants and lookup functions. Unicode-specific helpers.